#!/bin/bash

###
# VM@Work Tokamak 2.0.0
# Copyright Dave Parsons 2007 - 2008
# Updated for Fusion 2.0
###

# Called like: choice <promtp>
# e.g. choice "Do you want to play a game?"
# Returns: global variable CHOICE
function choice {
    CHOICE=''
    local prompt="$*"
    local answer
    read -p "$prompt" answer
    case "$answer" in
        [yY1] ) CHOICE='y';;
        [nN0] ) CHOICE='n';;
        * ) CHOICE="$answer";;
    esac
}

# Reset current VMware Fusion settings
function resetnet {
    # Loop thru possible vmnets
    # Maximum allowed is 100
    echo "VM@Work Tokamak 2.0.0: Removing networking configuration"
    rm "$LIBDIR/locations"
    rm "$LIBDIR/config"
    for ((i=0;i<=99;i+=1))
    do
        rm -R "$LIBDIR/vmnet$i" &>/dev/null
        rm "$LEASEDIR/vmnet-dhcpd-vmnet$i.leases" &>/dev/null
        rm "$LEASEDIR/vmnet-dhcpd-vmnet$i.leases~" &>/dev/null
    done
}

export PATH=/bin:/sbin:/usr/bin:/usr/sbin
LIBDIR="/Library/Application Support/VMware Fusion"
LEASEDIR="/var/db/vmware"
LAUNCHD="/Library/LaunchDaemons"
TOKDIR=`pwd`

# Check for root
if [ `id -u` != "0" ]; then
    echo "VM@Work Tokamak 2.0.0: Must be run as root!"
	exit 1
fi

case "$1" in
    --install)
    echo "VM@Work Tokamak 2.0.0: Installer started"
    # Stop VMware Fusion daemons and kexts if running
    # Use the Fusion scripts
    echo "VM@Work Tokamak 2.0.0: Stop daemons and kexts"
    "$LIBDIR/boot.sh" --stop &>/dev/null

    # Create a backup folder
    echo "VM@Work Tokamak 2.0.0: Create backup folders"
    mkdir -p "$TOKDIR/backup" &>/dev/null
    chmod 755 "$TOKDIR/backup" &>/dev/null
    mkdir -p "$TOKDIR/current" &>/dev/null
    chmod 755 "$TOKDIR/current" &>/dev/null

    # Backup original files
    echo "VM@Work Tokamak 2.0.0: Save original files"
    cp "$LIBDIR/locations" "$TOKDIR/backup/locations"
    cp "$LIBDIR/config" "$TOKDIR/backup/config"
    cp "$LAUNCHD/com.vmware.launchd.vmware.plist" \
       "$TOKDIR/backup/com.vmware.launchd.vmware.plist"

    # Modify LaunchDaemon plist
    echo "VM@Work Tokamak 2.0.0: Set boot script"
    defaults write "$LAUNCHD/com.vmware.launchd.vmware" \
        "ProgramArguments" -array \
        "$TOKDIR/tokamak-boot.sh" \
        "--start"
    #defaults read "$LAUNCHD/com.vmware.launchd.vmware"

    # Configure Tokamak networking
    "$TOKDIR/tokamak-config-net.pl"
    "$TOKDIR/tokamak-boot.sh" --start &>/dev/null

    # Display status
    "$0" --display

    echo "VM@Work Tokamak 2.0.0: Installer completed"
    ;;

    --uninstall)
    echo "VM@Work Tokamak 2.0.0: Uninstaller started"

    # Stop VMware Fusion daemons and kexts if running
    # Use the Tokamak scripts
    echo "VM@Work Tokamak 2.0.0: Stop daemons and kexts"
    "$TOKDIR/tokamak-boot.sh" --stop &>/dev/null

    # Reset Fusion networking
    # We always reset here so to ensure
    # we are back to original state
    resetnet

    # Restore original files
    echo "VM@Work Tokamak 2.0.0: Restore original files"
    cp "$TOKDIR/backup/locations" "$LIBDIR/locations"
    cp "$TOKDIR/backup/config" "$LIBDIR/config"
    cp "$TOKDIR/backup/com.vmware.launchd.vmware.plist" \
       "$LAUNCHD/com.vmware.launchd.vmware.plist"

    # Remove backup folders
    echo "VM@Work Tokamak 2.0.0: Remove backup folder"
    rm -R "$TOKDIR/backup"
    until [ "$CHOICE" = "y" -o "$CHOICE" = "n" ]; do
		choice "Do you want to save current Tokamak settings? [yes/no] "
		if [ "$CHOICE" = "n" ]; then
			rm -R "$TOKDIR/current"
		fi
    done

    # Restart original VMware Fusion scripts
    echo "VM@Work Tokamak 2.0.0: Start daemons and kexts"
    "$LIBDIR/vmware-config-net.pl"
    "$LIBDIR/boot.sh" --start &>/dev/null

    # Display status
    "$0" --display

    echo "VM@Work Tokamak 2.0.0: Uninstaller completed"
    ;;

    --reinstall)
    # Allow a reinstall
    "$0" --uninstall && "$0" --install
    ;;

    --modify)
    # Modify current Fusion network settings
    "$TOKDIR/tokamak-boot.sh" --stop &>/dev/null
    "$TOKDIR/tokamak-config-net.pl" -n
    cp "$LIBDIR/locations" "$TOKDIR/current/locations"
    cp "$LIBDIR/config" "$TOKDIR/current/config"
    "$TOKDIR/tokamak-boot.sh" --start &>/dev/null
    # Display status
    "$0" --display
    ;;

    --reset)
    # Reset current Fusion network settings
    until [ "$CHOICE" = "y" -o "$CHOICE" = "n" ]; do
        choice "Do you want to reset current network settings? [yes/no] "
        if [ "$CHOICE" = "y" ]; then
            # Configure Tokamak networking
            "$TOKDIR/tokamak-boot.sh" --stop &>/dev/null
   			 cp "$TOKDIR/backup/locations" "$LIBDIR/locations"
   			 cp "$TOKDIR/backup/config" "$LIBDIR/config"
    		"$TOKDIR/tokamak-boot.sh" --start &>/dev/null
            # Display status
            "$0" --display
        fi
    done
    ;;

    --reapply)
    # Reapply current Fusion network settings
    until [ "$CHOICE" = "y" -o "$CHOICE" = "n" ]; do
        choice "Do you want to reapply current network settings? [yes/no] "
        if [ "$CHOICE" = "y" ]; then
            # Configure Tokamak networking
            "$TOKDIR/tokamak-boot.sh" --stop &>/dev/null
   			 cp "$TOKDIR/current/locations" "$LIBDIR/locations"
   			 cp "$TOKDIR/current/config" "$LIBDIR/config"
    		"$TOKDIR/tokamak-boot.sh" --start &>/dev/null
            # Display status
            "$0" --display
        fi
    done
    ;;

    --display)
    # Display current Fusion network settings
    echo "VM@Work Tokamak 2.0.0: Display settings"
    "$TOKDIR/tokamak-config-net.pl" -d
    "$TOKDIR/tokamak-boot.sh" --status
    ;;

    *)
    echo "VM@Work Tokamak 2.0.0"
    echo "---------------------"
    echo "Usage: $0 {--install|--uninstall|--reinstall|--modify|--reset|--reapply|--display}"
    echo "--install   - setup the Tokamak replacement scripts and configure networks"
    echo "--uninstall - remove the Tokamak replacement scripts and reset networks"
    echo "--reinstall - reset and reinstall Tokamak"
    echo "--modify    - modify networks"
    echo "--reset     - reset networks"
    echo "--reapply   - reapply current configuration"
    echo "--display   - display current network settings"
    exit 1
esac
